@@ -99,11 +99,9 @@ class Repository(object):
         # Loading the appropriate backend
         # if requested
         if setupBackend:
-            if repo_additional_information:
-                r_last_update = repo_additional_information[
-                    'remote_last_update']
-                l_last_update = repo_additional_information[
-                    'local_last_update']
+            if repo_additional_information and self.name != "lbtaskrun":
+                r_last_update = repo_additional_information['remote_last_update']
+                l_last_update = repo_additional_information['local_last_update']
                 if r_last_update <= l_last_update and checkForUpdates is True:
                     log.info("Backend did not change, using local metadata")
                     checkForUpdates = False
