@@ -183,18 +183,30 @@ class InstallArea(object):  # IGNORE:R0902
         self.initfile = None
         self._checkRepository()
 
-    def createYumClient(self, checkForUpdates=True):
+    def createYumClient(self, checkForUpdates=True, forceCheckForUpdates=False):
         """ Creates a yum client
 
         :param checkForUpdates: Flag used to update the back end after setup
                                 based on the remote configuration
-
+        :param forceCheckForUpdates: Flag used enforce the update of the
+                                     repository based on the remote repo, even
+                                     if the local last updated time is newer
+                                     than the remote one. If this is False,
+                                     the the update of repo from
+                                     the remote one is done only if
+                                     the last updated time is newer
+                                     on the remote site than on local repo.
         :returns: the yum client object
         """
         from .DependencyManager import LbYumClient
         conf = dict([(k, v["url"]) for k, v in list(self.yumConfig.items())])
+        if not forceCheckForUpdates:
+            extra_conf = self.config.exrtrainfo
+        else:
+            extra_conf = {}
         return LbYumClient(self.siteroot, conf,
-                           checkForUpdates=checkForUpdates)
+                           checkForUpdates=checkForUpdates,
+                           repositories_extra_infos=extra_conf)
 
     def createDBManager(self, chainedDBManager):
         """
